# =============================================================
# ORGANICS
# =============================================================
		
# Set input files
result    <- read.csv(file.path(path, "Result_OneRowPerSample_Reprocessed.csv"), 1)
			
# Create a data frame with data from Organics sites		
OrganicsData    <- subset(result, TerrainType=="Organics")
OrganicsData    <- subset(OrganicsData, !is.na(OrganicsData$GWCWetBase_perc))
OrganicsPitData <- subset(OrganicsData, OrganicsData$Source != "Borehole")
  	
  		
# Reading data and defining objects
depth.min <- OrganicsData$FromDepth
depth.max <- OrganicsData$ToDepth
depth.ave <- OrganicsData$SampleDepth
depth.width <- depth.max-depth.min
GWC <- OrganicsData$GWCWetBase_perc
ICE <- OrganicsData$ExIceCont_perc
CAT <- OrganicsData$SolubleCations_meq100g
#SOM <- OrganicsData$SOM_perc	 # soil organic matter in percent
SOM=OrganicsData$SOCd	         # soil organic carbon density in kg C /m3	

# differing uncertainty width to propagate effects of uncertainty in estimating SOCd
SOCdh=OrganicsData$SOCd_high_scenario
SOCdl=OrganicsData$SOCd_low_scenario
	  		
# Calculate x and y values based on smooth.spline and supply to ggplot as lines
	# Perform smoothing spline with weights (w)
	w=1/(depth.width*100)^(1/4)
	manual.df=5.5

	GWC.spl.w 	<- smooth.spline(x=depth.ave, y=GWC, w=w, df=manual.df)
	ICE.spl.w 	<- smooth.spline(x=depth.ave, y=ICE, w=w, df=manual.df)   
	CAT.spl.w	<- smooth.spline(x=depth.ave, y=CAT, w=w, df=manual.df) 
	SOM.spl.w 	<- smooth.spline(x=depth.ave, y=SOM, w=w, df=manual.df)	

  	# differing uncertainty width to propagate effects of uncertainty in estimating SOCd
	SOCdh.spl.w 	<- smooth.spline(x=depth.ave, y=SOCdh, w=w, df=manual.df)
	SOCdl.spl.w 	<- smooth.spline(x=depth.ave, y=SOCdl, w=w, df=manual.df)
				
	# Calculate the standard error

	smooth.matrix=function(x, y, df){
  		n = length(x);
 		A = matrix(0, n, n);
  		for(i in 1:n){
   			y = rep(0, n); y[i]=1;
   			yi = predict(smooth.spline(x, y, df=df),x)$y;
    	    		A[,i]= yi;
  		 }
 		 (A+t(A))/2;
	}

	# Now, using the above function, we can calculate the covariance matrix COV for fitted values
	# GWC
	SGWC=smooth.matrix(depth.ave, GWC, GWC.spl.w$df)
	COV=var(GWC)*SGWC%*%t(SGWC)
	se.GWC=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# ICE
	SICE=smooth.matrix(depth.ave, ICE, ICE.spl.w$df)
	COV=var(ICE)*SICE%*%t(SICE)
	se.ICE=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# Cations
	SCAT=smooth.matrix(depth.ave, CAT, CAT.spl.w$df)
	COV=var(CAT)*SCAT%*%t(SCAT)
	se.CAT=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# Organic Matter
	SSOM=smooth.matrix(depth.ave, SOM, SOM.spl.w$df)
	COV=var(SOM)*SSOM%*%t(SSOM)
	se.SOM=sqrt(diag(COV)) # Standard error of fitted values(?)
	
#=== We are creating upper- and lower-bounds trend for GWC
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(GWC.spl.w, depth.ave)$y
	UB.fittedGWC=yhat+z*se.GWC
	LB.fittedGWC=yhat-z*se.GWC
	test=cbind(depth.ave, UB.fittedGWC, LB.fittedGWC)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for GWC
	OrganicsGWCX 	<- GWC.spl.w$x
	OrganicsGWCY 	<- GWC.spl.w$y
	OrganicsGWCUpper	<- test.unique[,1:2]
	OrganicsGWCLower	<- test.unique[,c(1,3)]
	
	OrganicsGWCData <- data.frame(OrganicsGWCX,OrganicsGWCY, 
	                              OrganicsGWCUpper, OrganicsGWCLower)
		
	OrganicsGWCData <- OrganicsGWCData[c("OrganicsGWCX", "OrganicsGWCY", 
	                                     "depth.ave", "UB.fittedGWC", "LB.fittedGWC")]
	OrganicsGWCData$UB.fittedGWC[OrganicsGWCData$UB.fittedGWC > 100] <- 100                                     
	
#=== We are creating upper- and lower-bounds for trend for ICE	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(ICE.spl.w, depth.ave)$y
	UB.fittedICE=yhat+z*se.ICE
	LB.fittedICE=yhat-z*se.ICE
	test=cbind(depth.ave, UB.fittedICE, LB.fittedICE)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for ICE
	OrganicsICEX 	<- ICE.spl.w$x
	OrganicsICEY 	<- ICE.spl.w$y
	OrganicsICEUpper	<- test.unique[,1:2]
	OrganicsICELower	<- test.unique[,c(1,3)]
	
	OrganicsICEData <- data.frame(OrganicsICEX,OrganicsICEY,
	                              OrganicsICEUpper, OrganicsICELower)
		
	OrganicsICEData <- OrganicsICEData[c("OrganicsICEX", "OrganicsICEY", 
	                                     "depth.ave", "UB.fittedICE","LB.fittedICE")]

	# catch lower bound below 0 that prevents plotting
	OrganicsICEData$LB.fittedICE[OrganicsICEData$LB.fittedICE < 0] <- 0                                  
	OrganicsICEData <- OrganicsICEData[OrganicsICEData$depth.ave > 0.7,]	
		
#=== We are creating upper- and lower-bounds for trend for Cations	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(CAT.spl.w, depth.ave)$y
	UB.fittedCAT=yhat+z*se.CAT
	LB.fittedCAT=yhat-z*se.CAT
	LB.fittedCAT <- ifelse(LB.fittedCAT < 0,0,LB.fittedCAT)
	test=cbind(depth.ave, UB.fittedCAT, LB.fittedCAT)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for CAT
	OrganicsCATX 	<- CAT.spl.w$x
	OrganicsCATY 	<- CAT.spl.w$y
	OrganicsCATUpper	<- test.unique[,1:2]
	OrganicsCATLower	<- test.unique[,c(1,3)]
	
	OrganicsCATData <- data.frame(OrganicsCATX,OrganicsCATY,
	                              OrganicsCATUpper, OrganicsCATLower)
	OrganicsCATData <- OrganicsCATData[c("OrganicsCATX", "OrganicsCATY", 
	                                     "depth.ave", "UB.fittedCAT","LB.fittedCAT")]

#=== We are creating upper- and lower-bounds for trend for SOM	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(SOM.spl.w, depth.ave)$y
	UB.fittedSOM=yhat+z*se.SOM
	LB.fittedSOM=yhat-z*se.SOM
	LB.fittedSOM <- ifelse(LB.fittedSOM < 0,0,LB.fittedSOM)
	test=cbind(depth.ave, UB.fittedSOM, LB.fittedSOM)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for SOM
	OrganicsSOMX 	<- SOM.spl.w$x
	OrganicsSOMY 	<- SOM.spl.w$y
	OrganicsSOMUpper	<- test.unique[,1:2]
	OrganicsSOMLower	<- test.unique[,c(1,3)]
	
	OrganicsSOMData <- data.frame(OrganicsSOMX,OrganicsSOMY,
	                              OrganicsSOMUpper, OrganicsSOMLower)
	OrganicsSOMData <- OrganicsSOMData[c("OrganicsSOMX", "OrganicsSOMY", 
	                                     "depth.ave", "UB.fittedSOM","LB.fittedSOM")]

    # differing uncertainty width to propagate effects of uncertainty in estimating SOCd
	OrganicsSOMData$UB.fittedSOM <- SOCdh.spl.w$y
	OrganicsSOMData$LB.fittedSOM <- SOCdl.spl.w$y

# ================================GGPLOT STARTED================================================

	plotGWCOrganics <- ggplot() +
	geom_rect(data=OrganicsData, 
	aes(xmin=0.345, xmax=0.45, ymin=0, ymax=100), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=OrganicsData, aes(SampleDepth, GWCWetBase_perc), size=0.5, color="black") +
	geom_point(data=OrganicsPitData, aes(SampleDepth, GWCWetBase_perc), size=0.5, color="green3") +
	geom_errorbarh(data = OrganicsData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = GWCWetBase_perc), size = 0.2, height = 0) +
	geom_errorbarh(data = OrganicsPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = GWCWetBase_perc), size = 0.2,height = 0, color="green3") +
    geom_line(data=OrganicsGWCData, aes(OrganicsGWCX, OrganicsGWCY), color='slateblue') +
	geom_ribbon(data = OrganicsGWCData, aes(x = depth.ave, ymin = LB.fittedGWC,
	ymax = UB.fittedGWC),alpha = 0.3, fill = 'lightslateblue') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 100), breaks = seq(0, 100, 20)) +
	ggtitle(bquote(paste("Water Content GWC"[w]," (%)"))) +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=75, label="b) Organic", size=3.5) 

	plotICEOrganics <- ggplot() +
	geom_rect(data=OrganicsData, 
	aes(xmin=0.345, xmax=0.45, ymin=0, ymax=100), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=OrganicsData, aes(SampleDepth, ExIceCont_perc), size=0.5, color="black") +
	geom_point(data=OrganicsPitData, aes(SampleDepth, ExIceCont_perc), size=0.5, color="green3") +
	geom_errorbarh(data = OrganicsData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = ExIceCont_perc), size = 0.2, height = 0) +
	geom_errorbarh(data = OrganicsPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = ExIceCont_perc), size = 0.2,height = 0, color="green3") +
    geom_line(data=OrganicsICEData, aes(OrganicsICEX, OrganicsICEY), color='blue') +
	geom_ribbon(data = OrganicsICEData, aes(x = depth.ave, ymin = LB.fittedICE,
	ymax = UB.fittedICE),alpha = 0.3, fill = 'blue') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 100), breaks = seq(0, 100, 20)) +
	ggtitle("Excess Ice Content (%)") +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=75, label="b) Organic", size=3.5) 
	
	plotCATOrganics <- ggplot() +
	geom_rect(data=OrganicsData, 
	aes(xmin=0.345, xmax=0.45, ymin=0, ymax=4), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=OrganicsData, aes(SampleDepth, SolubleCations_meq100g), size=0.5, color="black") +
	geom_point(data=OrganicsPitData, aes(SampleDepth, SolubleCations_meq100g), size=0.5,color="green3") +
	geom_errorbarh(data = OrganicsData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = SolubleCations_meq100g), size = 0.2, height = 0) +
	geom_errorbarh(data = OrganicsPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = SolubleCations_meq100g), size = 0.2,height = 0, color="green3") +
    geom_line(data=OrganicsCATData, aes(OrganicsCATX, OrganicsCATY), color='gray33') +
	geom_ribbon(data = OrganicsCATData, aes(x = depth.ave, ymin = LB.fittedCAT,
	ymax = UB.fittedCAT),alpha = 0.3, fill = 'gray33') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 4), breaks = seq(0, 4, 1)) +
	ggtitle("Soluble Cations \n(meq/100 g dry soil)") +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=3, label="b) Organic", size=3.5) 
	
	plotSOMOrganics <- ggplot() +
	geom_rect(data=OrganicsData, 
	aes(xmin=0.345, xmax=0.45, ymin=0, ymax=60), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=OrganicsData, aes(SampleDepth, SOCd), size=0.5, color="black") +
	geom_point(data=OrganicsPitData, aes(SampleDepth, SOCd), size=0.5,color="green3") +
	geom_errorbarh(data = OrganicsData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = SOCd), size = 0.2, height = 0) +
	geom_errorbarh(data = OrganicsPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = SOCd), size = 0.2,height = 0, color="green3") +
    geom_line(data=OrganicsSOMData, aes(OrganicsSOMX, OrganicsSOMY), color='violetred') +
	geom_ribbon(data = OrganicsSOMData, aes(x = depth.ave, ymin = LB.fittedSOM,
	ymax = UB.fittedSOM),alpha = 0.3, fill = 'violetred') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 60), breaks = seq(0, 60, 10)) +
	ggtitle("Organic Carbon (kg C"~m^-3*')') +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=45, label="b) Organic", size=3.5) 
	
	plot_grid(plotGWCOrganics,plotICEOrganics, plotCATOrganics, plotSOMOrganics, labels=c("A", "B", "C", "D"), align = 'h',ncol=4, nrow=1)





















  		