# =============================================================
# TILL
# =============================================================
		
# Set input files
result    <- read.csv(file.path(path, "Result_OneRowPerSample_Reprocessed.csv"), 1)
			
# Create a data frame with data from Organics sites		
TillData <- subset(result, TerrainType=="Till")
TillPitData <- subset(TillData, TillData$Source != "Borehole") 		
 		
 		
# Reading data and defining objects 
	depth.min=TillData$FromDepth
	depth.max=TillData$ToDepth
	depth.ave=TillData$SampleDepth
	depth.width=depth.max-depth.min
	GWC=TillData$GWCWetBase_perc
	ICE=TillData$ExIceCont_perc
	CAT=TillData$SolubleCations_meq100g
	#SOM=TillData$SOM_perc # soil organic matter in percent
  	SOM=TillData$SOCd	   # soil organic carbon density in kg C /m3	
  	
  	# differing uncertainty width to propagate effects of uncertainty in estimating SOCd
  	SOCdh=TillData$SOCd_high_scenario
  	SOCdl=TillData$SOCd_low_scenario
  	
  	# remove outliers that may artificially inflate the confidence interval
  	# coefficient is the multiplier of teh interquartile range used as cutoff 
  	# to detect outliers. The
  	coef <- 5
  	mask <- CAT < min(boxplot.stats(CAT,coef=coef)$out)
  	
# Calculate x and y values based on smooth.spline and spply to ggplot as line
# Perform smoothing spline with weights (w)
		w=1/(depth.width*100)^(1/4)
		manual.df=5.5

		GWC.spl.w 	<- smooth.spline(x=depth.ave, y=GWC, w=w, df=manual.df)
		ICE.spl.w 	<- smooth.spline(x=depth.ave, y=ICE, w=w, df=manual.df)   
		CAT.spl.w	<- smooth.spline(x=depth.ave[mask], y=CAT[mask], w=w[mask], df=manual.df) 
		SOM.spl.w 	<- smooth.spline(x=depth.ave, y=SOM, w=w, df=manual.df)
		
  	    # differing uncertainty width to propagate effects of uncertainty in estimating SOCd
		SOCdh.spl.w 	<- smooth.spline(x=depth.ave, y=SOCdh, w=w, df=manual.df)
		SOCdl.spl.w 	<- smooth.spline(x=depth.ave, y=SOCdl, w=w, df=manual.df)
				
	# Calculate the standard error

		smooth.matrix=function(x, y, df){
  		 n = length(x);
 		 A = matrix(0, n, n);
  		 for(i in 1:n){
   			y = rep(0, n); y[i]=1;
   			yi = predict(smooth.spline(x, y, df=df),x)$y;
    	    A[,i]= yi;
  		 }
 		 (A+t(A))/2;
		}

	# Now, using the above function, we can calculate the covariance matrix COV for fitted values
	
	# GWC
	SGWC=smooth.matrix(depth.ave, GWC, GWC.spl.w$df)
	COV=var(GWC)*SGWC%*%t(SGWC)
	se.GWC=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# ICE
	SICE=smooth.matrix(depth.ave, ICE, ICE.spl.w$df)
	COV=var(ICE)*SICE%*%t(SICE)
	se.ICE=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# Cations
	SCAT=smooth.matrix(depth.ave[mask], CAT[mask], CAT.spl.w$df)
	COV=var(CAT[mask])*SCAT%*%t(SCAT)
	se.CAT=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# Organic Matter
	SSOM=smooth.matrix(depth.ave, SOM, SOM.spl.w$df)
	COV=var(SOM)*SSOM%*%t(SSOM)
	se.SOM=sqrt(diag(COV)) # Standard error of fitted values(?)
	
#=== We are creating upper- and lower-bounds trend for GWC
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(GWC.spl.w, depth.ave)$y
	UB.fittedGWC=yhat+z*se.GWC
	LB.fittedGWC=yhat-z*se.GWC
	test=cbind(depth.ave, UB.fittedGWC, LB.fittedGWC)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for GWC
	TillGWCX 	<- GWC.spl.w$x
	TillGWCY 	<- GWC.spl.w$y
	TillGWCUpper	<- test.unique[,1:2]
	TillGWCLower	<- test.unique[,c(1,3)]
	
	TillGWCData <- data.frame(TillGWCX,TillGWCY,
	                          TillGWCUpper, TillGWCLower)
	TillGWCData <- TillGWCData[c("TillGWCX", "TillGWCY",
	                             "depth.ave", "UB.fittedGWC", "LB.fittedGWC")]
	#fix plotting flaw when bounda outside range
	TillGWCData$UB.fittedGWC[TillGWCData$UB.fittedGWC > 100] <- 100 
	
#=== We are creating upper- and lower-bounds for trend for ICE	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(ICE.spl.w, depth.ave)$y
	UB.fittedICE=yhat+z*se.ICE
	LB.fittedICE=yhat-z*se.ICE
	test=cbind(depth.ave, UB.fittedICE, LB.fittedICE)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for ICE
	TillICEX 	<- ICE.spl.w$x
	TillICEY 	<- ICE.spl.w$y
	TillICEUpper	<- test.unique[,1:2]
	TillICELower	<- test.unique[,c(1,3)]
	
	TillICEData <- data.frame(TillICEX,TillICEY,
	                          TillICEUpper, TillICELower)
		
	TillICEData <- TillICEData[c("TillICEX", "TillICEY",
	                             "depth.ave", "UB.fittedICE","LB.fittedICE")]
	TillICEData <- TillICEData[TillICEData$depth.ave > 0.7,]	
		
#=== We are creating upper- and lower-bounds for trend for Cations	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(CAT.spl.w, depth.ave[mask])$y
	UB.fittedCAT=yhat+z*se.CAT
	LB.fittedCAT=yhat-z*se.CAT
	test=cbind(depth.ave[mask], UB.fittedCAT, LB.fittedCAT)
	test.unique=test[!duplicated(depth.ave[mask]),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for CAT
	TillCATX 	<- CAT.spl.w$x
	TillCATY 	<- CAT.spl.w$y
	TillCATUpper	<- test.unique[,1:2]
	TillCATLower	<- test.unique[,c(1,3)]
	
	TillCATData <- data.frame(TillCATX,TillCATY,
	                          TillCATUpper, TillCATLower)
	names(TillCATData)[3] <- 'depth.ave'                          
	TillCATData <- TillCATData[c("TillCATX", "TillCATY", 
	                             "depth.ave", "UB.fittedCAT","LB.fittedCAT")]

	# fix negative lower bounds
	TillCATData$LB.fittedCAT[TillCATData$LB.fittedCAT < 0] <- 0
	
#=== We are creating upper- and lower-bounds for trend for SOM	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(SOM.spl.w, depth.ave)$y
	UB.fittedSOM=yhat+z*se.SOM
	LB.fittedSOM=yhat-z*se.SOM
	LB.fittedSOM <- ifelse(LB.fittedSOM < 0,0,LB.fittedSOM)
	test=cbind(depth.ave, UB.fittedSOM, LB.fittedSOM)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for SOM
	TillSOMX 	<- SOM.spl.w$x
	TillSOMY 	<- SOM.spl.w$y
	TillSOMUpper	<- test.unique[,1:2]
	TillSOMLower	<- test.unique[,c(1,3)]
	
	TillSOMData <- data.frame(TillSOMX,TillSOMY, 
	                          TillSOMUpper, TillSOMLower)
	TillSOMData <- TillSOMData[c("TillSOMX", "TillSOMY", 
	                             "depth.ave", "UB.fittedSOM","LB.fittedSOM")]
	                             
	# differing uncertainty width to propagate effects of uncertainty in estimating SOCd
	TillSOMData$UB.fittedSOM <- SOCdh.spl.w$y
	TillSOMData$LB.fittedSOM <- SOCdl.spl.w$y      
	                   

# ================================GGPLOT STARTED================================================

	plotGWCTill <- ggplot() +
	geom_rect(data=TillData, 
	aes(xmin=0.35, xmax=1.5, ymin=0, ymax=100), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=TillData, aes(SampleDepth, GWCWetBase_perc), size=0.5, color="black") +
	geom_point(data=TillPitData, aes(SampleDepth, GWCWetBase_perc), size=0.5, color="green3") +
	geom_errorbarh(data = TillData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = GWCWetBase_perc), size = 0.2, height = 0) +
	geom_errorbarh(data = TillPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = GWCWetBase_perc), size = 0.2,height = 0, color="green3") +
    geom_line(data=TillGWCData, aes(TillGWCX, TillGWCY), color='slateblue') +
	geom_ribbon(data = TillGWCData, aes(x = depth.ave, ymin = LB.fittedGWC,
	ymax = UB.fittedGWC),alpha = 0.3, fill = 'lightslateblue') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 100), breaks = seq(0, 100, 20)) +
	ggtitle(bquote(paste("Water Content GWC"[w]," (%)"))) +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=75, label="a) Till", size=3.5) 
	
	plotICETill <- ggplot() +
	geom_rect(data=TillData, 
	aes(xmin=0.35, xmax=1.5, ymin=0, ymax=100), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=TillData, aes(SampleDepth, ExIceCont_perc), size=0.5, color="black") +
	geom_point(data=TillPitData, aes(SampleDepth, ExIceCont_perc), size=0.5, color="green3") +
	geom_errorbarh(data = TillData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = ExIceCont_perc), size = 0.2, height = 0) +
	geom_errorbarh(data = TillPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = ExIceCont_perc), size = 0.2,height = 0, color="green3") +
    geom_line(data=TillICEData, aes(TillICEX, TillICEY), color='blue') +
	geom_ribbon(data = TillICEData, aes(x = depth.ave, ymin = LB.fittedICE,
	ymax = UB.fittedICE),alpha = 0.3, fill = 'blue') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 100), breaks = seq(0, 100, 20)) +
	ggtitle("Excess Ice Content (%)") +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=75, label="a) Till", size=3.5) 
	
	plotCATTill <- ggplot() +
	geom_rect(data=TillData, 
	aes(xmin=0.35, xmax=1.5, ymin=0, ymax=1.2), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=TillData, aes(SampleDepth, SolubleCations_meq100g), size=0.5, color="black") +
	geom_point(data=TillPitData, aes(SampleDepth, SolubleCations_meq100g), size=0.5,color="green3") +
	geom_errorbarh(data = TillData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = SolubleCations_meq100g), size = 0.2, height = 0) +
	geom_errorbarh(data = TillPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = SolubleCations_meq100g), size = 0.2,height = 0, color="green3") +
    geom_line(data=TillCATData, aes(TillCATX, TillCATY), color='gray33') +
	geom_ribbon(data = TillCATData, aes(x = depth.ave, ymin = LB.fittedCAT,
	ymax = UB.fittedCAT),alpha = 0.3, fill = 'gray33') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 1.2), breaks = seq(0, 1.2, 0.3)) +
	ggtitle("Soluble Cations \n(meq/100 g dry soil)") +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=0.9, label="a) Till", size=3.5) 
	
	plotSOMTill <- ggplot() +
	geom_rect(data=TillData, 
	aes(xmin=0.35, xmax=1.5, ymin=0, ymax=60), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=TillData, aes(SampleDepth, SOCd), size=0.5, color="black") +
	geom_point(data=TillPitData, aes(SampleDepth, SOCd), size=0.5,color="green3") +
	geom_errorbarh(data = TillData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = SOCd), size = 0.2, height = 0) +
	geom_errorbarh(data = TillPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = SOCd), size = 0.2,height = 0, color="green3") +
    geom_line(data=TillSOMData, aes(TillSOMX, TillSOMY), color='violetred') +
	geom_ribbon(data = TillSOMData, aes(x = depth.ave, ymin = LB.fittedSOM,
	ymax = UB.fittedSOM),alpha = 0.3, fill = 'violetred') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 60), breaks = seq(0, 60, 10)) +
	ggtitle("Organic Carbon (kg C"~m^-3*')') +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=45, label="a) Till", size=3.5) 
	
	plot_grid(plotGWCTill,plotICETill, plotCATTill, plotSOMTill, labels=c("A", "B", "C", "D"), align = 'h',ncol=4, nrow=1) 





















  		