# =============================================================
# VALLEY
# =============================================================
		
# Set input files
result    <- read.csv(file.path(path, "Result_OneRowPerSample_Reprocessed.csv"), 1)
			
# Create a data frame with data from Organics sites		
ValleyData    <- subset(result, TerrainType=="Valley")
ValleyPitData <- subset(ValleyData, ValleyData$Source != "Borehole") 		
  	
 # Reading data and defining objects
	depth.min=ValleyData$FromDepth
	depth.max=ValleyData$ToDepth
	depth.ave=ValleyData$SampleDepth
	depth.width=depth.max-depth.min
	GWC=ValleyData$GWCWetBase_perc
	ICE=ValleyData$ExIceCont_perc
	CAT=ValleyData$SolubleCations_meq100g
	#SOM=ValleyData$SOM_perc # soil organic matter in percent
  	SOM=ValleyData$SOCd	# soil organic carbon density in kg C /m3	

  	# differing uncertainty width to propagate effects of uncertainty in estimating SOCd
  	SOCdh= ValleyData$SOCd_high_scenario
  	SOCdl= ValleyData$SOCd_low_scenario
  		
  	# remove outliers that may artificially inflate the confidence interval
  	# coefficient is the multiplier of teh interquartile range used as cutoff 
  	# to detect outliers. The
  	coef <- 5
  	mask <- CAT < min(boxplot.stats(CAT,coef=coef)$out)
  	
# Calculate x and y values based on smooth.spline and spply to ggplot as line
# Perform smoothing spline with weights (w)
		w=1/(depth.width*100)^(1/4)
		manual.df=5.5

		GWC.spl.w 	<- smooth.spline(x=depth.ave, y=GWC, w=w, df=manual.df)
		ICE.spl.w 	<- smooth.spline(x=depth.ave, y=ICE, w=w, df=manual.df)   
		CAT.spl.w	<- smooth.spline(x=depth.ave[mask], y=CAT[mask], w=w[mask], df=manual.df) 
		SOM.spl.w 	<- smooth.spline(x=depth.ave, y=SOM, w=w, df=manual.df)
		
  	    # differing uncertainty width to propagate effects of uncertainty in estimating SOCd
		SOCdh.spl.w 	<- smooth.spline(x=depth.ave, y=SOCdh, w=w, df=manual.df)
		SOCdl.spl.w 	<- smooth.spline(x=depth.ave, y=SOCdl, w=w, df=manual.df)
				
	# Calculate the standard error

		smooth.matrix=function(x, y, df){
  		 n = length(x);
 		 A = matrix(0, n, n);
  		 for(i in 1:n){
   			y = rep(0, n); y[i]=1;
   			yi = predict(smooth.spline(x, y, df=df),x)$y;
    	    A[,i]= yi;
  		 }
 		 (A+t(A))/2;
		}

	# Now, using the above function, we can calculate the covariance matrix COV for fitted values
	
	# GWC
	SGWC=smooth.matrix(depth.ave, GWC, GWC.spl.w$df)
	COV=var(GWC)*SGWC%*%t(SGWC)
	se.GWC=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# ICE
	SICE=smooth.matrix(depth.ave, ICE, ICE.spl.w$df)
	COV=var(ICE)*SICE%*%t(SICE)
	se.ICE=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# Cations
	SCAT=smooth.matrix(depth.ave[mask], CAT[mask], CAT.spl.w$df)
	COV=var(CAT[mask])*SCAT%*%t(SCAT)
	se.CAT=sqrt(diag(COV)) # Standard error of fitted values(?)
	
	# Organic Matter
	#SSOM=smooth.matrix(SOM$ValleyData.SampleDepth, SOM$ValleyData.SOM_perc, SOM.spl.w$df)
	#COV=var(SOM$ValleyData.SOM_perc)*SSOM%*%t(SSOM)
	SSOM=smooth.matrix(depth.ave, SOM, SOM.spl.w$df)
	COV=var(SOM)*SSOM%*%t(SSOM)
	se.SOM=sqrt(diag(COV)) # Standard error of fitted values(?)
	
#=== We are creating upper- and lower-bounds trend for GWC
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(GWC.spl.w, depth.ave)$y
	UB.fittedGWC=yhat+z*se.GWC
	LB.fittedGWC=yhat-z*se.GWC
	test=cbind(depth.ave, UB.fittedGWC, LB.fittedGWC)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for GWC
	ValleyGWCX 	<- GWC.spl.w$x
	ValleyGWCY 	<- GWC.spl.w$y
	ValleyGWCUpper	<- test.unique[,1:2]
	ValleyGWCLower	<- test.unique[,c(1,3)]
	
	ValleyGWCData <- data.frame(ValleyGWCX,ValleyGWCY,
	                            ValleyGWCUpper, ValleyGWCLower)
		
	ValleyGWCData <- ValleyGWCData[c("ValleyGWCX", "ValleyGWCY",
	                                 "depth.ave", "UB.fittedGWC", "LB.fittedGWC")]
	# catch lower bound below 0 that prevents plotting
	ValleyGWCData$LB.fittedGWC[ValleyGWCData$LB.fittedGWC < 0] <- 0 
                               
	
#=== We are creating upper- and lower-bounds for trend for ICE	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(ICE.spl.w, depth.ave)$y
	UB.fittedICE=yhat+z*se.ICE
	LB.fittedICE=yhat-z*se.ICE
	test=cbind(depth.ave, UB.fittedICE, LB.fittedICE)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for ICE
	ValleyICEX 	<- ICE.spl.w$x
	ValleyICEY 	<- ICE.spl.w$y
	ValleyICEUpper	<- test.unique[,1:2]
	ValleyICELower	<- test.unique[,c(1,3)]
	
	ValleyICEData <- data.frame(ValleyICEX,ValleyICEY,
	                            ValleyICEUpper, ValleyICELower)
		
	ValleyICEData <- ValleyICEData[c("ValleyICEX", "ValleyICEY", 
	                                 "depth.ave", "UB.fittedICE","LB.fittedICE")]
	# catch lower bound below 0 that prevents plotting
	ValleyICEData$LB.fittedICE[ValleyICEData$LB.fittedICE < 0] <- 0                                  
	ValleyICEData <- ValleyICEData[ValleyICEData$depth.ave > 0.7,]	  
		
#=== We are creating upper- and lower-bounds for trend for Cations	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	yhat=predict(CAT.spl.w, depth.ave[mask])$y
	UB.fittedCAT=yhat+z*se.CAT
	LB.fittedCAT=yhat-z*se.CAT
	test=cbind(depth.ave[mask], UB.fittedCAT, LB.fittedCAT)
	test.unique=test[!duplicated(depth.ave[mask]),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for CAT
	ValleyCATX 	<- CAT.spl.w$x
	ValleyCATY 	<- CAT.spl.w$y
	ValleyCATUpper	<- test.unique[,1:2]
	ValleyCATLower	<- test.unique[,c(1,3)]
	
	ValleyCATData <- data.frame(ValleyCATX,ValleyCATY,
	                            ValleyCATUpper, ValleyCATLower)
	names(ValleyCATData)[3] <- 'depth.ave' 		
	ValleyCATData <- ValleyCATData[c("ValleyCATX", "ValleyCATY",
	                                 "depth.ave", "UB.fittedCAT","LB.fittedCAT")]
	# catch lower bound below 0 that prevents plotting                                 
	ValleyCATData$LB.fittedCAT[ValleyCATData$LB.fittedCAT < 0] <- 0                                 

#=== We are creating upper- and lower-bounds for trend for SOM	
	a=0.05 #type I error rate
	z=qnorm(1-a/2) # coefficient for confidence interval (i.e., to create (1-a)100% CI)
	#yhat=predict(SOM.spl.w, SOM$ValleyData.SampleDepth)$y
	yhat=predict(SOM.spl.w, depth.ave)$y
	UB.fittedSOM=yhat+z*se.SOM
	LB.fittedSOM=yhat-z*se.SOM
	LB.fittedSOM <- ifelse(LB.fittedSOM < 0,0,LB.fittedSOM)
	#test=cbind(SOM$ValleyData.SampleDepth, UB.fittedSOM, LB.fittedSOM)
	#test.unique=test[!duplicated(SOM$ValleyData.SampleDepth),]
	test=cbind(depth.ave, UB.fittedSOM, LB.fittedSOM)
	test.unique=test[!duplicated(depth.ave),]
	ind=order(test.unique[,1])
	test.unique=test.unique[ind,]
	
	# Create a new data frame with average, upper and lower limits for SOM
	ValleySOMX 	<- SOM.spl.w$x
	ValleySOMY 	<- SOM.spl.w$y
	ValleySOMUpper	<- test.unique[,1:2]
	ValleySOMLower	<- test.unique[,c(1,3)]
	
	ValleySOMData <- data.frame(ValleySOMX, ValleySOMY, 
	                            ValleySOMUpper, ValleySOMLower)
		
	ValleySOMData <- ValleySOMData[c("ValleySOMX", "ValleySOMY", 
	                                 "depth.ave", "UB.fittedSOM","LB.fittedSOM")]
	                                 
    # differing uncertainty width to propagate effects of uncertainty in estimating SOCd
	ValleySOMData$UB.fittedSOM <- SOCdh.spl.w$y
	ValleySOMData$LB.fittedSOM <- SOCdl.spl.w$y

# ================================GGPLOT STARTED================================================

	plotGWCValley <- ggplot() +
	geom_rect(data=ValleyData, 
	aes(xmin=0.275, xmax=1, ymin=0, ymax=100), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=ValleyData, aes(SampleDepth, GWCWetBase_perc), size=0.5, color="black") +
	geom_point(data=ValleyPitData, aes(SampleDepth, GWCWetBase_perc), size=0.5, color="green3") +
	geom_errorbarh(data = ValleyData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = GWCWetBase_perc), size = 0.2, height = 0) +
	geom_errorbarh(data = ValleyPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = GWCWetBase_perc), size = 0.2,height = 0, color="green3") +
    geom_line(data=ValleyGWCData, aes(ValleyGWCX, ValleyGWCY), color='slateblue') +
	geom_ribbon(data = ValleyGWCData, aes(x = depth.ave, ymin = LB.fittedGWC,
	ymax = UB.fittedGWC),alpha = 0.3, fill = 'lightslateblue') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 100), breaks = seq(0, 100, 20)) +
	ggtitle(bquote(paste("Water Content GWC"[w]," (%)"))) +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=75, label="c) Valley", size=3.5) 

	plotICEValley <- ggplot() +
	geom_rect(data=ValleyData, 
	aes(xmin=0.275, xmax=1, ymin=0, ymax=100), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=ValleyData, aes(SampleDepth, ExIceCont_perc), size=0.5, color="black") +
	geom_point(data=ValleyPitData, aes(SampleDepth, ExIceCont_perc), size=0.5, color="green3") +
	geom_errorbarh(data = ValleyData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = ExIceCont_perc), size = 0.2, height = 0) +
	geom_errorbarh(data = ValleyPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = ExIceCont_perc), size = 0.2,height = 0, color="green3") +
    geom_line(data=ValleyICEData, aes(ValleyICEX, ValleyICEY), color='blue') +
	geom_ribbon(data = ValleyICEData, aes(x = depth.ave, ymin = LB.fittedICE,
	ymax = UB.fittedICE),alpha = 0.3, fill = 'blue') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 100), breaks = seq(0, 100, 20)) +
	ggtitle("Excess Ice Content (%)") +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=75, label="c) Valley", size=3.5) 
	
	plotCATValley <- ggplot() +
	geom_rect(data=ValleyData, 
	aes(xmin=0.275, xmax=1, ymin=0, ymax=4), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=ValleyData, aes(SampleDepth, SolubleCations_meq100g), size=0.5, color="black") +
	geom_point(data=ValleyPitData, aes(SampleDepth, SolubleCations_meq100g), size=0.5,color="green3") +
	geom_errorbarh(data = ValleyData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = SolubleCations_meq100g), size = 0.2, height = 0) +
	geom_errorbarh(data = ValleyPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = SolubleCations_meq100g), size = 0.2,height = 0, color="green3") +
    geom_line(data=ValleyCATData, aes(ValleyCATX, ValleyCATY), color='gray33') +
	geom_ribbon(data = ValleyCATData, aes(x = depth.ave, ymin = LB.fittedCAT,
	ymax = UB.fittedCAT),alpha = 0.3, fill = 'gray33') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 4), breaks = seq(0, 4, 1)) +
	ggtitle("Soluble Cations \n(meq/100 g dry soil)") +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=3, label="c) Valley", size=3.5) 
	
	plotSOMValley <- ggplot() +
	geom_rect(data=ValleyData, 
	aes(xmin=0.275, xmax=1, ymin=0, ymax=60), alpha=0.025, fill= 'lightgreen') +
	geom_point(data=ValleyData, aes(SampleDepth, SOCd), size=0.5, color="black") +
	geom_point(data=ValleyPitData, aes(SampleDepth, SOCd), size=0.5,color="green3") +
	geom_errorbarh(data = ValleyData, aes(x = SampleDepth, xmin = FromDepth, 
	xmax = ToDepth, y = SOCd), size = 0.2, height = 0) +
	geom_errorbarh(data = ValleyPitData, aes(x = SampleDepth, xmin = FromDepth,
    xmax = ToDepth, y = SOCd), size = 0.2,height = 0, color="green3") +
    geom_line(data=ValleySOMData, aes(ValleySOMX, ValleySOMY), color='violetred') +
	geom_ribbon(data = ValleySOMData, aes(x = depth.ave, ymin = LB.fittedSOM,
	ymax = UB.fittedSOM),alpha = 0.3, fill = 'violetred') +
	coord_flip() + theme_bw(12) +
	scale_x_reverse(lim = c(10, 0), breaks = seq(0, 10, 1)) +
	scale_y_continuous(lim = c(0, 60), breaks = seq(0, 60, 10)) +
	ggtitle("Organic Carbon (kg C"~m^-3*')') +  xlab('Depth (m)') + ylab('') + 
	theme(plot.title = element_text(size=10, colour="black", hjust=0.5)) +
	annotate("text", x=9.75, y=45, label="c) Valley", size=3.5) 
	
	plot_grid(plotGWCValley,plotICEValley, plotCATValley, plotSOMValley, labels=c("A", "B", "C", "D"), align = 'h',ncol=4, nrow=1)





















  		